/*----------------------------------------------------------------------------------
*
* COPYRIGHT (c) 2001 by Singing Electrons, Inc. All rights reserved.
*
* Module Name			: C:\se\adi\hidclass\Source\HidClass.h
*
* Description			: Contains prototypes and definitions for the HID Class implementation
*
*
* Revision History	: At bottom of the file.
*
*---------------------------------------------------------------------------------*/
#ifndef _HIDCLASS_H
#define _HIDCLASS_H


#define USB_HID_CLASS 3
#define USB_HID_SUBCLASS_NONE 0
#define USB_HID_SUBCLASS_BOOT 1

#define USB_HID_PROTOCOL_NONE 0
#define USB_HID_PROTOCOL_KEYBOARD 1
#define USB_HID_PROTOCOL_MOUSE 2

#define USB_HID_DESCRIPTOR_HID 0x21
#define USB_HID_DESCRIPTOR_REPORT 0x22
#define USB_HID_DESCRIPTOR_PHYSICAL 0x23

#define USB_HID_GET_REPORT_REQUEST 0x01
#define USB_HID_SET_REPORT_REQUEST 0x09

#define USB_HID_COUNTRY_NONE 0
#define USB_HID_COUNTRY_US 33


#define HID_USAGE_PAGE 0x05
#define HID_USAGE_PAGE_LONG 0x06
#define HID_USAGE_PAGE_UNDEFINED 0x00
#define HID_USAGE_PAGE_DESKTOP 0x01
#define HID_USAGE_PAGE_BUTTONS 0x09
#define HID_USAGE_PAGE_MYOWN 0xff00

#define HID_USAGE  0x09
#define HID_USAGE_UNDEFINED  0x00
#define HID_USAGE_MOUSE  0x02
#define HID_USAGE_POINTER  0x01
#define HID_USAGE_X  0x30
#define HID_USAGE_Y  0x31

#define HID_USAGE_IODEVICE 0x01 //my own


#define HID_USAGE_MINIMUM 0x19
#define HID_USAGE_MAXIMUM 0x29
#define HID_LOGICAL_MINIMUM 0x15
#define HID_LOGICAL_MAXIMUM 0x25


#define HID_REPORT_COUNT 0x95
#define HID_REPORT_SIZE 0x75
#define HID_CONSTANT 01

#define HID_INPUT 0x81
#define HID_OUTPUT 0x91
#define HID_FEATURE 0xb1
#define HID_DATA_VARIABLE_ABSOLUTE 02
#define HID_DATA_VARIABLE_RELATIVE 06

#define HID_BEGIN_COLLECTION 0xA1
#define HID_END_COLLECTION 0xC0
#define HID_COLLECTION_PHYSICAL 0x00
#define HID_COLLECTION_APPLICATION 0x01


typedef bool (* PGETREPORTPROC) (uint16 reportTypeAndID, void *buffer, PUINT pNumBytesToTransfer);
typedef bool (* PSETREPORTPROC) (uint16 reportTypeAndID, void *buffer, UINT numBytesInReport);
typedef void (* PREPORTSENTPROC) (void);
typedef void (* PNAKSENTPROC) (void);

bool HIDCLASS_Init (uint16 vid, uint16 pid, uint16 rel, bool useINEP, PUCHAR pReportDescriptor, uint16 reportDescriptorSize,
	PGETREPORTPROC pOnGetReportProc, PSETREPORTPROC pOnSetReportProc,
	PREPORTSENTPROC pOnReportSentProc, PNAKSENTPROC pOnNAKSentProc, PSUSPENDPROC pOnSuspendProc, 
	PRESUMEPROC pOnResumeProc, PRESETPROC pOnResetProc);

void HIDCLASS_PrepareReportEndpoint (PUCHAR pReportData, uint16 reportSize);

#endif //end of _HIDCLASS_H

/*----------------------------------------------------------------------------------
* $Log: HidClass.h,v $
* Revision 1.2  2002/10/30 02:36:41  Devendra
* - Added more abstraction to HIDCLASS. So that it's possible to build
*   different devices without making any changes to the HIDCLASS module.
* - Added proper support for handling USB SUSPEND, RESUME, and RESET events.
*
* Revision 1.1  2002/10/22 17:23:39  Devendra
* Rearranged file locations.
*
* Revision 1.4  2002/10/14 05:16:04  Devendra
* - Custom Device now using Feature reports for I/O
* - Added compiler define/project configuration to switch between mouse and custom device.
*
* Revision 1.3  2002/10/14 01:33:15  Devendra
* Got "custom" device functional with buttons and lights!
*
* Revision 1.2  2002/10/09 17:09:32  Devendra
* - Added support for handling IN endpoints.
* - Added HID descriptors (HID and HID Report)
* - Modified the Interface descriptors to comply to HID Class Spec.
* - Added functionality to use the push-buttons on the Eagle-35 as a mouse (for buttons as well as for movement).
* - The device is now a fully functioning USB Mouse!
*
* Revision 1.1  2002/09/20 06:51:30  Devendra
* First Rev.
*
*
*---------------------------------------------------------------------------------*/
